import Layout from '@/layout'
import { h, resolveComponent } from 'vue'

const ActualTimeRoutes = {
  path: '/realTime',
  component: Layout,
  name: 'realTime',
  redirect: '/realTime/departure',
  //using el svg icon, the elSvgIcon first when at the same time using elSvgIcon and icon
  meta: {
    title: '综合可视化',
    elSvgIcon: 'DataAnalysis',
    breadcrumb: false,
    roles: ['integrated_visualization_menu'],
  },
  children: [
    {
      path: '/realTime/departure',
      name: 'Departure',
      redirect: '/realTime/departure/airport',
      meta: {
        title: '国内出港',
        breadcrumb: false,
        roles: ['view_of_domestic_departure_termina_page'],
      },
      component: {
        render: () => h(resolveComponent('router-view')),
      },
      children: [
        {
          path: '/realTime/departure/airport',
          name: 'DepartureAirport',
          meta: {
            title: '国内出港航站视图',
          },
          component: {
            render: () => h(resolveComponent('router-view')),
          },
          children: [
            {
              path: '/realTime/departure/airport',
              name: 'DepartureAirportView',
              component: () =>
                import('@/views/realTime/departure/airport/index.vue'),
            },
            {
              path: '/realTime/departure/flight',
              name: 'DepartureFlight',
              meta: {
                title: '国内出港航班视图',
              },
              component: {
                render: () => h(resolveComponent('router-view')),
              },
              children: [
                {
                  path: '/realTime/departure/flight',
                  name: 'DepartureFlightView',
                  component: () =>
                    import('@/views/realTime/departure/flight/index.vue'),
                },
                {
                  path: '/realTime/departure/waybill',
                  name: 'DepartureWaybill',
                  meta: {
                    title: '国内出港运单视图',
                  },
                  component: {
                    render: () => h(resolveComponent('router-view')),
                  },
                  children: [
                    {
                      path: '/realTime/departure/waybill',
                      name: 'DepartureWaybillView',
                      component: () =>
                        import('@/views/realTime/departure/waybill/index.vue'),
                    },
                    {
                      path: '/realTime/departure/goods',
                      name: 'DepartureGoods',
                      meta: {
                        title: '国内出港货物视图',
                      },
                      component: () =>
                        import('@/views/realTime/departure/goods/index.vue'),
                    },
                  ],
                },
              ],
            },
          ],
        },
      ],
    },
    {
      path: '/realTime/internationalDeparture',
      name: 'InternationalDeparture',
      redirect: '/realTime/internationalDeparture/airport',
      meta: {
        title: '国际出港',
        roles: ['view_of_international_departure_terminal_page'],
        breadcrumb: false,
      },
      component: {
        render: () => h(resolveComponent('router-view')),
      },
      children: [
        {
          path: '/realTime/internationalDeparture/airport',
          name: 'InternationalDepartureAirport',
          meta: { title: '国际出港航站视图' },
          component: {
            render: () => h(resolveComponent('router-view')),
          },
          children: [
            {
              path: '/realTime/internationalDeparture/airport',
              name: 'InternationalDepartureAirportView',
              component: () =>
                import(
                  '@/views/realTime/internationalDeparture/airport/index.vue'
                ),
            },
            {
              path: '/realTime/internationalDeparture/flight',
              name: 'InternationalDepartureFlight',
              meta: {
                title: '国际出港航班视图',
              },
              component: {
                render: () => h(resolveComponent('router-view')),
              },
              children: [
                {
                  path: '/realTime/internationalDeparture/flight',
                  name: 'InternationalDepartureFlightView',
                  component: () =>
                    import(
                      '@/views/realTime/internationalDeparture/flight/index.vue'
                    ),
                },
                {
                  path: '/realTime/internationalDeparture/waybill',
                  name: 'InternationalDepartureWaybill',
                  meta: {
                    title: '国际出港运单视图',
                  },
                  component: {
                    render: () => h(resolveComponent('router-view')),
                  },
                  children: [
                    {
                      path: '/realTime/internationalDeparture/waybill',
                      name: 'InternationalDepartureWaybillView',
                      component: () =>
                        import(
                          '@/views/realTime/internationalDeparture/waybill/index.vue'
                        ),
                    },
                    {
                      path: '/realTime/internationalDeparture/goods',
                      name: 'InternationalDepartureGoods',
                      meta: {
                        title: '国际出港货物视图',
                      },
                      component: () =>
                        import(
                          '@/views/realTime/internationalDeparture/goods/index.vue'
                        ),
                    },
                  ],
                },
              ],
            },
          ],
        },
      ],
    },
    {
      path: '/realTime/arrival',
      name: 'Arrival',
      redirect: '/realTime/arrival/airport',
      meta: {
        title: '国内进港',
        roles: ['view_of_domestic_inbound_termina_page'],
        breadcrumb: false,
      },
      component: {
        render: () => h(resolveComponent('router-view')),
      },
      children: [
        {
          path: '/realTime/arrival/airport',
          name: 'ArrivalAirport',
          meta: { title: '国内进港航站视图' },
          component: {
            render: () => h(resolveComponent('router-view')),
          },
          children: [
            {
              path: '/realTime/arrival/airport',
              name: 'ArrivalAirportView',
              component: () =>
                import('@/views/realTime/arrival/airport/index.vue'),
            },
            {
              path: '/realTime/arrival/flight',
              name: 'ArrivalFlight',
              meta: {
                title: '国内进港航班视图',
              },
              component: {
                render: () => h(resolveComponent('router-view')),
              },
              children: [
                {
                  path: '/realTime/arrival/flight',
                  name: 'ArrivalFlightView',
                  component: () =>
                    import('@/views/realTime/arrival/flight/index.vue'),
                },
                {
                  path: '/realTime/arrival/waybill',
                  name: 'ArrivalWaybill',
                  meta: {
                    title: '国内进港运单视图',
                  },
                  component: {
                    render: () => h(resolveComponent('router-view')),
                  },
                  children: [
                    {
                      path: '/realTime/arrival/waybill',
                      name: 'ArrivalWaybillView',
                      component: () =>
                        import('@/views/realTime/arrival/waybill/index.vue'),
                    },
                    {
                      path: '/realTime/arrival/goods',
                      name: 'ArrivalGoods',
                      meta: {
                        title: '国内进港货物视图',
                      },
                      component: () =>
                        import('@/views/realTime/arrival/goods/index.vue'),
                    },
                  ],
                },
              ],
            },
          ],
        },
      ],
    },
    {
      path: '/realTime/internationalArrival',
      name: 'InternationalArrival',
      redirect: '/realTime/internationalArrival/airport',
      meta: {
        title: '国际进港',
        roles: ['view_of_international_inbound_terminal_page'],
        breadcrumb: false,
      },
      component: {
        render: () => h(resolveComponent('router-view')),
      },
      children: [
        {
          path: '/realTime/internationalArrival/airport',
          name: 'InternationalArrivalAirport',
          meta: { title: '国际进港航站视图' },
          component: {
            render: () => h(resolveComponent('router-view')),
          },
          children: [
            {
              path: '/realTime/internationalArrival/airport',
              name: 'InternationalArrivalAirportView',
              component: () =>
                import(
                  '@/views/realTime/internationalArrival/airport/index.vue'
                ),
            },
            {
              path: '/realTime/internationalArrival/flight',
              name: 'InternationalArrivalFlight',
              meta: {
                title: '国际进港航班视图',
              },
              component: {
                render: () => h(resolveComponent('router-view')),
              },
              children: [
                {
                  path: '/realTime/internationalArrival/flight',
                  name: 'InternationalArrivalFlightView',
                  component: () =>
                    import(
                      '@/views/realTime/internationalArrival/flight/index.vue'
                    ),
                },
                {
                  path: '/realTime/internationalArrival/waybill',
                  name: 'InternationalArrivalWaybill',
                  meta: {
                    title: '国际进港运单视图',
                  },
                  component: {
                    render: () => h(resolveComponent('router-view')),
                  },
                  children: [
                    {
                      path: '/realTime/internationalArrival/waybill',
                      name: 'InternationalArrivalWaybillView',
                      component: () =>
                        import(
                          '@/views/realTime/internationalArrival/waybill/index.vue'
                        ),
                    },
                    {
                      path: '/realTime/internationalArrival/goods',
                      name: 'InternationalArrivalGoods',
                      meta: {
                        title: '国际进港货物视图',
                      },
                      component: () =>
                        import(
                          '@/views/realTime/internationalArrival/goods/index.vue'
                        ),
                    },
                  ],
                },
              ],
            },
          ],
        },
      ],
    },
    {
      path: '/realTime/trackMap',
      name: 'TrackMap',
      meta: { title: '轨迹地图', roles: ['track_map_page'] },
      component: () => import('@/views/realTime/trackMap/index.vue'),
    },
  ],
}

export default [ActualTimeRoutes]
